@@ -3,7 +3,6 @@
 //! <https://en.wikipedia.org/wiki/Differential_evolution>
 use self::Strategy::*;
 use crate::{utility::*, *};
-use ndarray::{s, Array1};
 
 /// The Differential Evolution strategy.
 ///
@@ -49,7 +48,7 @@ pub enum Strategy {
     S10,
 }
 
-setting_builder! {
+setting! {
     /// Differential Evolution settings.
     pub struct De {
         @base,
@@ -168,7 +167,7 @@ impl Algorithm for Method {
                     continue 'a;
                 }
             }
-            let tmp_f = ctx.func.fitness(&tmp, &ctx.report);
+            let tmp_f = ctx.func.fitness(tmp.as_slice().unwrap(), &ctx.report);
             if tmp_f < ctx.fitness[i] {
                 ctx.assign_from(i, tmp_f, &tmp);
             }
