@@ -2,9 +2,8 @@
 //!
 //! <https://en.wikipedia.org/wiki/Particle_swarm_optimization>
 use crate::{thread_pool::ThreadPool, utility::*, *};
-use ndarray::s;
 
-setting_builder! {
+setting! {
     /// Particle Swarm Optimization settings.
     pub struct Pso {
         @base,
