@@ -2,20 +2,17 @@
 //!
 //! <https://doi.org/10.1016/j.cad.2010.12.015>
 use crate::{utility::*, *};
-use ndarray::s;
 
-setting_builder! {
+setting! {
     /// Teaching Learning Based Optimization settings.
-    pub struct Tlbo {
-        @base,
-    }
+    pub struct Tlbo(@base);
 }
 
 impl Setting for Tlbo {
     type Algorithm = Method;
 
     fn base(&self) -> &BasicSetting {
-        &self.base
+        &self.0
     }
 
     fn create(self) -> Self::Algorithm {
@@ -28,7 +25,7 @@ pub struct Method;
 
 impl Method {
     fn register<F: ObjFunc>(ctx: &mut Context<F>, i: usize, student: &Array1<f64>) {
-        let f_new = ctx.func.fitness(student, &ctx.report);
+        let f_new = ctx.func.fitness(student.as_slice().unwrap(), &ctx.report);
         if f_new < ctx.fitness[i] {
             ctx.pool.slice_mut(s![i, ..]).assign(student);
             ctx.fitness[i] = f_new;
