@@ -11,23 +11,26 @@
 pub use crate::random::*;
 use crate::{thread_pool::ThreadPool, *};
 use alloc::{sync::Arc, vec::Vec};
-use ndarray::s;
+pub use ndarray::{s, Array1, Array2, AsArray};
 
-setting_builder! {
+setting! {
     /// Setting base.
     pub struct BasicSetting {
         /// Termination condition.
-        task: Task = Task::MaxGen(200),
+        pub task: Task = Task::MaxGen(200),
         /// Population number.
-        pop_num: usize = 200,
+        pub pop_num: usize = 200,
         /// The report frequency. (per generation)
-        rpt: u32 = 1,
+        pub rpt: u32 = 1,
     }
 }
 
 /// A trait that provides a conversion to original setting.
 ///
-/// Can be auto implemented through [`setting_builder!`].
+/// The setting type is actually a builder of the [`Setting::Algorithm`] type.
+///
+/// Before the implementation,
+/// the builder function of the setting type can be implemented by [`setting!`].
 pub trait Setting {
     /// Associated algorithm.
     type Algorithm: Algorithm;
@@ -99,7 +102,9 @@ impl<F: ObjFunc> Context<F> {
 
     /// Get fitness from individual `i`.
     pub fn fitness(&mut self, i: usize) {
-        self.fitness[i] = self.func.fitness(self.pool.slice(s![i, ..]), &self.report);
+        self.fitness[i] = self
+            .func
+            .fitness(self.pool.slice(s![i, ..]).as_slice().unwrap(), &self.report);
     }
 
     pub(crate) fn init_pop(&mut self) {
@@ -180,9 +185,9 @@ impl<F: ObjFunc> Context<F> {
     }
 }
 
-/// The methods of the metaheuristic algorithms.
+/// The methods of the meta-heuristic algorithms.
 ///
-/// + First, use [`setting_builder!`] macro to build a "setting" type.
+/// + First, use [`setting!`] macro to build a "setting" type.
 /// + Second, implement [`Setting`] trait then indicate to a "method" type.
 /// + Last, implement `Algorithm` trait on the "method" type.
 ///
@@ -191,15 +196,18 @@ impl<F: ObjFunc> Context<F> {
 /// So the "method" type is used to store the additional data if any.
 ///
 /// ```
-/// use metaheuristics_nature::{setting_builder, utility::*, ObjFunc};
+/// use metaheuristics_nature::{setting, utility::*, ObjFunc};
 ///
-/// setting_builder! {
-///     pub struct MySetting {
+/// setting! {
+///     /// A setting with additional fields.
+///     pub struct MySetting1 {
 ///         @base,
+///         my_option: u32 = 20,
 ///     }
 /// }
 ///
-/// impl Setting for MySetting {
+/// /// The implementation of the structure with fields.
+/// impl Setting for MySetting1 {
 ///     type Algorithm = Method;
 ///     fn base(&self) -> &BasicSetting {
 ///         &self.base
@@ -209,6 +217,22 @@ impl<F: ObjFunc> Context<F> {
 ///     }
 /// }
 ///
+/// setting! {
+///     /// Tuple-like setting.
+///     pub struct MySetting2(@base);
+/// }
+///
+/// /// The implementation of a tuple-like structure.
+/// impl Setting for MySetting2 {
+///     type Algorithm = Method;
+///     fn base(&self) -> &BasicSetting {
+///         &self.0
+///     }
+///     fn create(self) -> Self::Algorithm {
+///         Method
+///     }
+/// }
+///
 /// pub struct Method;
 ///
 /// impl Algorithm for Method {
@@ -222,7 +246,7 @@ impl<F: ObjFunc> Context<F> {
 /// All you have to do is implement the "initialization" method and
 /// "generation" method, which are corresponded to the [`Algorithm::init`] and
 /// [`Algorithm::generation`] respectively.
-pub trait Algorithm: Sized {
+pub trait Algorithm {
     /// Initialization implementation.
     ///
     /// The information of the [`Context`] can be obtained or modified at this phase preliminarily.
